summaryrefslogtreecommitdiffstats
path: root/chrome/browser/views/frame/browser_view.h
diff options
context:
space:
mode:
authoroshima@chromium.org <oshima@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-01-16 19:04:59 +0000
committeroshima@chromium.org <oshima@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-01-16 19:04:59 +0000
commit8c8804a595cd215d4a0ff6a3fbf0919b40dfac00 (patch)
treefe685a665febc0209b52abcc2cb0317c74c63f08 /chrome/browser/views/frame/browser_view.h
parent858d4887816dc5239921900f205351d740f38176 (diff)
downloadchromium_src-8c8804a595cd215d4a0ff6a3fbf0919b40dfac00.zip
chromium_src-8c8804a595cd215d4a0ff6a3fbf0919b40dfac00.tar.gz
chromium_src-8c8804a595cd215d4a0ff6a3fbf0919b40dfac00.tar.bz2
Revert "Refactoring to reduce chromeos dependency in chrome."
This reverts commit 8ae39b4c6290397c03661b59619e125f416a9af8. TBR=sky@chromium.org BUG=none TEST=interactive_ui_tests on windows should pass with revert. Review URL: http://codereview.chromium.org/542098 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@36461 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/views/frame/browser_view.h')
-rw-r--r--chrome/browser/views/frame/browser_view.h17
1 files changed, 4 insertions, 13 deletions
diff --git a/chrome/browser/views/frame/browser_view.h b/chrome/browser/views/frame/browser_view.h
index e786228..c6dc2ce 100644
--- a/chrome/browser/views/frame/browser_view.h
+++ b/chrome/browser/views/frame/browser_view.h
@@ -36,7 +36,7 @@ class BookmarkBarView;
class Browser;
class BrowserBubble;
class BrowserExtender;
-class BrowserViewLayoutManager;
+class BrowserLayoutManager;
class DownloadShelfView;
class EncodingMenuModel;
class ExtensionShelf;
@@ -367,25 +367,16 @@ class BrowserView : public BrowserWindow,
views::View* child);
virtual void ChildPreferredSizeChanged(View* child);
- // Factory Methods.
- // Returns a new LayoutManager for this browser view. A subclass may
- // override to implemnet different layout pocily.
- virtual views::LayoutManager* CreateLayoutManager() const;
-
- // Returns a new TabStrip for the browser view. A subclass may
- // override to return a different TabStrip implementation.
- virtual TabStrip* CreateTabStrip(TabStripModel* tab_strip_model) const;
-
private:
// Browser window related initializations.
- virtual void Init();
+ void Init();
#if defined(OS_WIN)
// Creates the system menu.
void InitSystemMenu();
#endif
- // Returns the BrowserViewLayoutManager.
- BrowserViewLayoutManager* GetBrowserViewLayoutManager() const;
+ // Returns the BrowserLayoutManager.
+ BrowserLayoutManager* GetBrowserLayoutManager() const;
// Prepare to show the Bookmark Bar for the specified TabContents. Returns
// true if the Bookmark Bar can be shown (i.e. it's supported for this